import React, { useState, useEffect, useRef } from 'react';
import { Button, Modal, Select, Form, message } from 'antd';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import moment from 'moment';
import { history } from 'umi';
import PageTable from '@/components/PageTable';
import { getDeviceList, deleteDevice, addDevice } from '@/services/device';
import { getMachineryList } from '@/services/machinery';
import { getMachineryTypeList } from '@/services/machineryType';

const formatterTime = (val) => {
  return val && val !== '-' ? moment(val).format('YYYY-MM-DD') : '-';
};

export default (props) => {
  // 绑定表单
  const formItemLayout = { labelCol: { span: 6 }, wrapperCol: { span: 14 } };
  const [form] = Form.useForm();
  const [editModal, setEditModal] = useState(false);
  const [loading, setLoading] = useState(false);
  const [machineryId, setMachineryId] = useState();
  const [device, setDeviceList] = useState();
  const [deviceId, setDeviceId] = useState();
  const actionRef = useRef();
  const [machineryTypeList, setMachineryTypeList] = useState([]);
  const [typeId, setTypeId] = useState();
  const [machineryList, setMachineryList] = useState([]);
  const { Option } = Select;
  const FormItem = Form.Item;

  const goBack = () => {
    history.goBack();
  };

  //列表编辑
  const handelEdit = (val) => {
    if (val.machineryId != null) {
      setEditModal(false);
      const title = '确认当前设备要解绑"' + val.machineryName + '"农机设备吗？';
      Modal.confirm({
        title: title,
        okText: '确认',
        cancelText: '取消',
        onOk () {
          deleteDevice(machineryId)
            .then(() => {
              setLoading(false);
              message.success(`解绑成功`);
              onCancel();
              actionRef.current.reload();

            })
            .catch((err) => {
              setLoading(false);
              message.error(err.message || err);
            });
        }
      })
    } else {
      setEditModal(true);
      setDeviceList(val);
    }

    form.setFieldsValue(val);
  };

  //绑定弹窗关闭
  const onCancel = () => {
    setMachineryId();
    form.resetFields();
    setEditModal(false);
  };

  // 绑定提交
  const Submit = (values) => {
    let params = { ...device, ...values };
    setLoading(true);
    addDevice(params).then((res) => {
      setLoading(false);
      message.success(`绑定成功`);
      actionRef.current.reload();
      goBack();
    });
  };

  useEffect(() => {
    getMachineryTypeList({ pageSize: 999 }).then((res) => {
      setMachineryTypeList(res.records);
    }).catch((err) => {
      console.log(err.message)
    });
  }, []);

  useEffect(() => {
    if (typeId) {
      getMachineryList({ typeId }).then((e) => {
        setMachineryList(e.records);
      }).catch((err) => {
        console.log(err.message)
      });
    }

  }, [typeId])

  const columns = [
    {
      title: '行号',
      dataIndex: 'deviceId',
      key: 'deviceId',
    },
    {
      title: '设备编号',
      dataIndex: 'deviceNo',
      key: 'deviceNo',
      search: false,
    },
    {
      title: '设备类型',
      dataIndex: 'deviceType',
      key: 'deviceType',
      valueEnum: {
        shensong: {
          text: '深松',
        },
        feifang: {
          text: '飞防',
        },
      },
      // request: () => queryTable(getDeviceList)(),
    },
    {
      title: '在线状态',
      dataIndex: 'onlineStatus',
      key: 'onlineStatus',
      render: (_, record) => {
        return record.onlineStatus === 1 ? '在线' : '离线';
      },
    },
    {
      title: '注册时间',
      dataIndex: 'createDate',
      key: 'createDate',
      render: formatterTime,
      search: false,
      width: 240,
    },
    {
      title: '绑定农机',
      dataIndex: 'machineryId',
      key: 'machineryId',
      search: false,
    },
    {
      title: '操作',
      valueType: 'option',
      width: 160,
      render: (_, record) => [
        <Button type="link" style={{ padding: 0 }} key={1}>
          查看作业
        </Button>,
        <Button type="link" style={{ padding: 0 }} key={2}>
          修改
        </Button>,
        <Button style={{ padding: 0 }} type="link" key={3} onClick={() => handelEdit(record)}>
          {record.machineryId === null ? '绑定' : '解绑'}
        </Button>,
      ],
    },
  ];

  return (
    <PageHeaderWrapper>
      <PageTable
        request={getDeviceList}
        columns={columns}
        actionRef={actionRef}
        rowKey="deviceId"
        options={false}
        toolBarRender={() => [
          <Button
            key="1"
            type="primary"
          >
            +同步设备信息
          </Button>,
        ]}
        scroll={{ x: 1000 }}
      />
      <Modal
        forceRender
        title="绑定农机"
        visible={editModal}
        onCancel={onCancel}
        keyboard={false}
        maskClosable={false}
        destroyOnClose={true}
        footer={null}
        machineryId={machineryId}
      >
        <Form  {...formItemLayout} onFinish={Submit} form={form}>
          <FormItem label="农机分类" name="typeId" rules={[{ required: true, message: '请选择农机分类' }]}>
            <Select value={typeId} onChange={setTypeId} allowClear style={{ width: '320px' }}>
              {machineryTypeList.map((item) => (
                <Option value={item.typeId} key={item.typeId}>
                  {item.name}
                </Option>
              ))}
            </Select>
          </FormItem>
          <FormItem label="选择农机" name="machineryId" rules={[{ required: true, message: '请选择农机名' }]}>
            <Select value={machineryId} onChange={setMachineryId} allowClear style={{ width: '320px' }}>
              {machineryList.map((item) => (
                <Option value={item.machineryId} key={item.machineryId}>
                  {item.name}
                </Option>
              ))}
            </Select>
          </FormItem>
          <FormItem label=" " colon={false}>
            <Button type="default" onClick={onCancel} style={{ marginTop: '2em', marginLeft: '4em' }}>
              取消
            </Button>
            <Button
              type="primary"
              loading={loading}
              htmlType="Submit"
              style={{ marginTop: '2em', marginLeft: '2em' }}
            >
              确认
            </Button>
          </FormItem>
        </Form>
      </Modal>
    </PageHeaderWrapper>
  );
};
